Bt97Flutterplugin class

Constructors

Bt97Flutterplugin()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

disconnectDevice() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openDeviceConnection(String mac) Future<String?>
printData(String str, int style, int size, int align) → dynamic
printQRCode(String str) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited